@@ -9,7 +9,7 @@ use Net::LDAP::Class::MethodMaker (
     'scalar --get_set_init' => [qw( default_home_dir default_email_suffix )],
 );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 NAME
 
@@ -21,7 +21,7 @@ Net::LDAP::Class::User::AD - Active Directory User class
  package MyLDAPUser;
  use base qw( Net::LDAP::Class::User::AD );
  
- __PACKAGE__->meta->setup(
+ __PACKAGE__->metadata->setup(
     base_dn             => 'dc=mycompany,dc=com',
     attributes          => __PACKAGE__->AD_attributes,
     unique_attributes   => __PACKAGE__->AD_unique_attributes,
